@@ -216,12 +216,23 @@ impl Reader{
         //edit empty
         //----------------------------
         if total_len == empty.0{
+            match self.empty_map.get_mut(&empty_index){
+                Some(e)=>{
+                    self.empty_start.remove(&e.1.0);
+                    self.empty_end.remove(&e.1.1);
+                },
+                None=>{
+                    return Err("failed-edit-empty");
+                }
+            }
             self.empty_map.remove(&empty_index);
         } else {
             match self.empty_map.get_mut(&empty_index){
                 Some(e)=>{
+                    self.empty_start.remove(&e.1.0);
                     e.1.0 = empty.1.0 + total_len;
                     e.0 = e.1.1 - e.1.0 + 1;
+                    self.empty_start.insert(e.1.0,empty_index);
                 },
                 None=>{
                     return Err("failed-edit-empty");
@@ -256,6 +267,8 @@ impl Reader{
 
         let mut previous_empty_index:usize = 0;
         let mut previous_empty_found = false;
+        //if boundry start position is greater then zero
+        //check if there is a empty ending at previous position
         if pointer.0.0 > 0{
             match self.empty_end.get(&(pointer.0.0 - 1)){
                 Some(v)=>{
@@ -277,6 +290,7 @@ impl Reader{
         }
 
         if previous_empty_found{
+            // println!("previous found");
             let mut next_empty_end = 0;
             //remove previous start pointer
             self.empty_end.remove(&self.empty_map[&previous_empty_index].1.1);
@@ -346,11 +360,24 @@ impl Reader{
     }
     pub fn map(&mut self,buffer:&mut Vec<u8>){
 
+        // println!("mapping len : {:?}",buffer.len());
+
         loop{
 
+            // if self.buffer.len() == 0{
+            //     break;
+            // }
+
+            // let pointer_time = Instant::now();
             match read(self,buffer){
                 Ok(v)=>{
 
+                    // println!("pointer_time : {:?}",pointer_time.elapsed());
+
+                    // println!("pointer found");
+
+                    // println!("{:?}",buffer.len());
+
                     //extract pointer from buffer
                     let pointer_len = v.boundry.0.1-v.boundry.0.0+1;
                     let new_buffer = self.buffer.split_off(v.boundry.1.1+1);
@@ -360,6 +387,7 @@ impl Reader{
 
                     //collect values
                     if self.find_values && !self.get_values_controll{
+                        // println!("find values");
                         for i in self.to_find.iter(){
                             if i == &v.key.2{
                                 let mut collect_value:Vec<u8> = vec![];
@@ -371,6 +399,7 @@ impl Reader{
                         }
                     } else
                     if self.get_values_controll{
+                        // println!("get values");
                         let mut collect_value:Vec<u8> = vec![];
                         for i in v.value.1.0..v.value.1.1{
                             collect_value.push(old_buffer[i]);
@@ -391,9 +420,17 @@ impl Reader{
                         }
                     }
 
+                    // println!("old buffer : {:?}",old_buffer.len());
+
+                    
+
                     //place new buffer
                     self.buffer = new_buffer;
 
+                    // println!("pointer_finish : {:?}",pointer_time.elapsed());
+
+                    
+
                 },
                 Err(_e)=>{
                     break;
@@ -544,11 +581,15 @@ fn read(reader:&mut Reader,buffer:&mut Vec<u8>)->Result<Pointer,&'static str>{
         
     //find flag
     if reader.flag.0 == false {
+        // let start_flag_time = Instant::now();
         match vector_in_vector(&reader.buffer,&vec![0,1,0],reader.buffer_cursor){
             Ok(l)=>{
+                // println!("start_flag_time : {:?}",start_flag_time.elapsed());
                 reader.no_flag_in_buffer = false;
                 if l.0 > 0{
+                    // let unhandled_time = Instant::now();
                     unhandled::init(reader,l.0);
+                    // println!("unhandled_time : {:?}",unhandled_time.elapsed());
                 }
                 if true {
                     reader.flag.0 = true;
